@@ -21,7 +21,7 @@ from qtpy.QtCore import Signal, Slot
 # Local imports
 from spyder.config.base import _
 from spyder.config.utils import get_edit_extensions
-from spyder.py3compat import getcwd
+from spyder.utils.misc import getcwd_or_home
 from spyder.utils import icon_manager as ima
 from spyder.utils.qthelpers import create_action, MENU_SEPARATOR
 from spyder.widgets.findinfiles import FindInFilesWidget
@@ -74,7 +74,7 @@ class FindInFiles(FindInFilesWidget, SpyderPluginMixin):
     
     def refreshdir(self):
         """Refresh search directory"""
-        self.find_options.set_directory(getcwd())
+        self.find_options.set_directory(getcwd_or_home())
 
     def set_project_path(self, path):
         """Refresh current project path"""
